@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -45,9 +45,7 @@ extern "C" {
  */
 static SDL_bool loaded_xinput = SDL_FALSE;
 
-
-int
-SDL_XINPUT_HapticInit(void)
+int SDL_XINPUT_HapticInit(void)
 {
     if (SDL_GetHintBoolean(SDL_HINT_XINPUT_ENABLED, SDL_TRUE)) {
         loaded_xinput = (WIN_LoadXInputDLL() == 0) ? SDL_TRUE : SDL_FALSE;
@@ -63,8 +61,7 @@ SDL_XINPUT_HapticInit(void)
     return 0;
 }
 
-int
-SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
+int SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
 {
     const Uint8 userid = (Uint8)dwUserid;
     SDL_hapticlist_item *item;
@@ -77,13 +74,13 @@ SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
     /* Make sure we don't already have it */
     for (item = SDL_hapticlist; item; item = item->next) {
         if (item->bXInputHaptic && item->userid == userid) {
-            return -1;  /* Already added */
+            return -1; /* Already added */
         }
     }
 
     SDL_zero(state);
     if (XINPUTSETSTATE(dwUserid, &state) != ERROR_SUCCESS) {
-        return -1;  /* no force feedback on this device. */
+        return -1; /* no force feedback on this device. */
     }
 
     item = (SDL_hapticlist_item *)SDL_malloc(sizeof(SDL_hapticlist_item));
@@ -96,7 +93,7 @@ SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
     /* !!! FIXME: I'm not bothering to query for a real name right now (can we even?) */
     {
         char buf[64];
-        SDL_snprintf(buf, sizeof(buf), "XInput Controller #%u", (unsigned int)(userid + 1));
+        (void)SDL_snprintf(buf, sizeof(buf), "XInput Controller #%u", userid + 1);
         item->name = SDL_strdup(buf);
     }
 
@@ -112,8 +109,7 @@ SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
     return SDL_SYS_AddHapticDevice(item);
 }
 
-int
-SDL_XINPUT_HapticMaybeRemoveDevice(const DWORD dwUserid)
+int SDL_XINPUT_HapticMaybeRemoveDevice(const DWORD dwUserid)
 {
     const Uint8 userid = (Uint8)dwUserid;
     SDL_hapticlist_item *item;
@@ -147,10 +143,9 @@ SDL_XINPUT_HapticMaybeRemoveDevice(const DWORD dwUserid)
  * Mostly, this is here to get rumbling to work, and all the other features
  *  are absent in the XInput path for now.  :(
  */
-static int SDLCALL
-SDL_RunXInputHaptic(void *arg)
+static int SDLCALL SDL_RunXInputHaptic(void *arg)
 {
-    struct haptic_hwdata *hwdata = (struct haptic_hwdata *) arg;
+    struct haptic_hwdata *hwdata = (struct haptic_hwdata *)arg;
 
     while (!SDL_AtomicGet(&hwdata->stopThread)) {
         SDL_Delay(50);
@@ -169,11 +164,10 @@ SDL_RunXInputHaptic(void *arg)
     return 0;
 }
 
-static int
-SDL_XINPUT_HapticOpenFromUserIndex(SDL_Haptic *haptic, const Uint8 userid)
+static int SDL_XINPUT_HapticOpenFromUserIndex(SDL_Haptic *haptic, const Uint8 userid)
 {
     char threadName[32];
-    XINPUT_VIBRATION vibration = { 0, 0 };  /* stop any current vibration */
+    XINPUT_VIBRATION vibration = { 0, 0 }; /* stop any current vibration */
     XINPUTSETSTATE(userid, &vibration);
 
     haptic->supported = SDL_HAPTIC_LEFTRIGHT;
@@ -189,9 +183,9 @@ SDL_XINPUT_HapticOpenFromUserIndex(SDL_Haptic *haptic, const Uint8 userid)
     }
     /* Clear the memory */
     SDL_memset(haptic->effects, 0,
-        sizeof(struct haptic_effect) * haptic->neffects);
+               sizeof(struct haptic_effect) * haptic->neffects);
 
-    haptic->hwdata = (struct haptic_hwdata *) SDL_malloc(sizeof(*haptic->hwdata));
+    haptic->hwdata = (struct haptic_hwdata *)SDL_malloc(sizeof(*haptic->hwdata));
     if (haptic->hwdata == NULL) {
         SDL_free(haptic->effects);
         haptic->effects = NULL;
@@ -210,7 +204,7 @@ SDL_XINPUT_HapticOpenFromUserIndex(SDL_Haptic *haptic, const Uint8 userid)
         return SDL_SetError("Couldn't create XInput haptic mutex");
     }
 
-    SDL_snprintf(threadName, sizeof(threadName), "SDLXInputDev%d", (int)userid);
+    (void)SDL_snprintf(threadName, sizeof(threadName), "SDLXInputDev%d", userid);
     haptic->hwdata->thread = SDL_CreateThreadInternal(SDL_RunXInputHaptic, threadName, 64 * 1024, haptic->hwdata);
 
     if (haptic->hwdata->thread == NULL) {
@@ -224,20 +218,17 @@ SDL_XINPUT_HapticOpenFromUserIndex(SDL_Haptic *haptic, const Uint8 userid)
     return 0;
 }
 
-int
-SDL_XINPUT_HapticOpen(SDL_Haptic * haptic, SDL_hapticlist_item *item)
+int SDL_XINPUT_HapticOpen(SDL_Haptic *haptic, SDL_hapticlist_item *item)
 {
     return SDL_XINPUT_HapticOpenFromUserIndex(haptic, item->userid);
 }
 
-int
-SDL_XINPUT_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_XINPUT_JoystickSameHaptic(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
-    return (haptic->hwdata->userid == joystick->hwdata->userid);
+    return haptic->hwdata->userid == joystick->hwdata->userid;
 }
 
-int
-SDL_XINPUT_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_XINPUT_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     SDL_hapticlist_item *item;
     int index = 0;
@@ -254,16 +245,14 @@ SDL_XINPUT_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
     return SDL_SetError("Couldn't find joystick in haptic device list");
 }
 
-void
-SDL_XINPUT_HapticClose(SDL_Haptic * haptic)
+void SDL_XINPUT_HapticClose(SDL_Haptic *haptic)
 {
     SDL_AtomicSet(&haptic->hwdata->stopThread, 1);
     SDL_WaitThread(haptic->hwdata->thread, NULL);
     SDL_DestroyMutex(haptic->hwdata->mutex);
 }
 
-void
-SDL_XINPUT_HapticQuit(void)
+void SDL_XINPUT_HapticQuit(void)
 {
     if (loaded_xinput) {
         WIN_UnloadXInputDLL();
@@ -271,15 +260,13 @@ SDL_XINPUT_HapticQuit(void)
     }
 }
 
-int
-SDL_XINPUT_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * base)
+int SDL_XINPUT_HapticNewEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *base)
 {
-    SDL_assert(base->type == SDL_HAPTIC_LEFTRIGHT);  /* should catch this at higher level */
+    SDL_assert(base->type == SDL_HAPTIC_LEFTRIGHT); /* should catch this at higher level */
     return SDL_XINPUT_HapticUpdateEffect(haptic, effect, base);
 }
 
-int
-SDL_XINPUT_HapticUpdateEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * data)
+int SDL_XINPUT_HapticUpdateEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *data)
 {
     XINPUT_VIBRATION *vib = &effect->hweffect->vibration;
     SDL_assert(data->type == SDL_HAPTIC_LEFTRIGHT);
@@ -287,18 +274,17 @@ SDL_XINPUT_HapticUpdateEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
     vib->wLeftMotorSpeed = data->leftright.large_magnitude * 2;
     vib->wRightMotorSpeed = data->leftright.small_magnitude * 2;
     SDL_LockMutex(haptic->hwdata->mutex);
-    if (haptic->hwdata->stopTicks) {  /* running right now? Update it. */
+    if (haptic->hwdata->stopTicks) { /* running right now? Update it. */
         XINPUTSETSTATE(haptic->hwdata->userid, vib);
     }
     SDL_UnlockMutex(haptic->hwdata->mutex);
     return 0;
 }
 
-int
-SDL_XINPUT_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect, Uint32 iterations)
+int SDL_XINPUT_HapticRunEffect(SDL_Haptic *haptic, struct haptic_effect *effect, Uint32 iterations)
 {
     XINPUT_VIBRATION *vib = &effect->hweffect->vibration;
-    SDL_assert(effect->effect.type == SDL_HAPTIC_LEFTRIGHT);  /* should catch this at higher level */
+    SDL_assert(effect->effect.type == SDL_HAPTIC_LEFTRIGHT); /* should catch this at higher level */
     SDL_LockMutex(haptic->hwdata->mutex);
     if (effect->effect.leftright.length == SDL_HAPTIC_INFINITY || iterations == SDL_HAPTIC_INFINITY) {
         haptic->hwdata->stopTicks = SDL_HAPTIC_INFINITY;
@@ -307,15 +293,14 @@ SDL_XINPUT_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect, Ui
     } else {
         haptic->hwdata->stopTicks = SDL_GetTicks() + (effect->effect.leftright.length * iterations);
         if ((haptic->hwdata->stopTicks == SDL_HAPTIC_INFINITY) || (haptic->hwdata->stopTicks == 0)) {
-            haptic->hwdata->stopTicks = 1;  /* fix edge cases. */
+            haptic->hwdata->stopTicks = 1; /* fix edge cases. */
         }
     }
     SDL_UnlockMutex(haptic->hwdata->mutex);
     return (XINPUTSETSTATE(haptic->hwdata->userid, vib) == ERROR_SUCCESS) ? 0 : -1;
 }
 
-int
-SDL_XINPUT_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_XINPUT_HapticStopEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     XINPUT_VIBRATION vibration = { 0, 0 };
     SDL_LockMutex(haptic->hwdata->mutex);
@@ -324,44 +309,37 @@ SDL_XINPUT_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
     return (XINPUTSETSTATE(haptic->hwdata->userid, &vibration) == ERROR_SUCCESS) ? 0 : -1;
 }
 
-void
-SDL_XINPUT_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+void SDL_XINPUT_HapticDestroyEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     SDL_XINPUT_HapticStopEffect(haptic, effect);
 }
 
-int
-SDL_XINPUT_HapticGetEffectStatus(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_XINPUT_HapticGetEffectStatus(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticSetGain(SDL_Haptic * haptic, int gain)
+int SDL_XINPUT_HapticSetGain(SDL_Haptic *haptic, int gain)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
+int SDL_XINPUT_HapticSetAutocenter(SDL_Haptic *haptic, int autocenter)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticPause(SDL_Haptic * haptic)
+int SDL_XINPUT_HapticPause(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticUnpause(SDL_Haptic * haptic)
+int SDL_XINPUT_HapticUnpause(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticStopAll(SDL_Haptic * haptic)
+int SDL_XINPUT_HapticStopAll(SDL_Haptic *haptic)
 {
     XINPUT_VIBRATION vibration = { 0, 0 };
     SDL_LockMutex(haptic->hwdata->mutex);
@@ -381,113 +359,94 @@ SDL_XINPUT_HapticStopAll(SDL_Haptic * haptic)
 
 typedef struct SDL_hapticlist_item SDL_hapticlist_item;
 
-int
-SDL_XINPUT_HapticInit(void)
+int SDL_XINPUT_HapticInit(void)
 {
     return 0;
 }
 
-int
-SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
+int SDL_XINPUT_HapticMaybeAddDevice(const DWORD dwUserid)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticMaybeRemoveDevice(const DWORD dwUserid)
+int SDL_XINPUT_HapticMaybeRemoveDevice(const DWORD dwUserid)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticOpen(SDL_Haptic * haptic, SDL_hapticlist_item *item)
+int SDL_XINPUT_HapticOpen(SDL_Haptic *haptic, SDL_hapticlist_item *item)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_XINPUT_JoystickSameHaptic(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticOpenFromJoystick(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_XINPUT_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
     return SDL_Unsupported();
 }
 
-void
-SDL_XINPUT_HapticClose(SDL_Haptic * haptic)
+void SDL_XINPUT_HapticClose(SDL_Haptic *haptic)
 {
 }
 
-void
-SDL_XINPUT_HapticQuit(void)
+void SDL_XINPUT_HapticQuit(void)
 {
 }
 
-int
-SDL_XINPUT_HapticNewEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * base)
+int SDL_XINPUT_HapticNewEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *base)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticUpdateEffect(SDL_Haptic * haptic, struct haptic_effect *effect, SDL_HapticEffect * data)
+int SDL_XINPUT_HapticUpdateEffect(SDL_Haptic *haptic, struct haptic_effect *effect, SDL_HapticEffect *data)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect, Uint32 iterations)
+int SDL_XINPUT_HapticRunEffect(SDL_Haptic *haptic, struct haptic_effect *effect, Uint32 iterations)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_XINPUT_HapticStopEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     return SDL_Unsupported();
 }
 
-void
-SDL_XINPUT_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+void SDL_XINPUT_HapticDestroyEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
 }
 
-int
-SDL_XINPUT_HapticGetEffectStatus(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_XINPUT_HapticGetEffectStatus(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticSetGain(SDL_Haptic * haptic, int gain)
+int SDL_XINPUT_HapticSetGain(SDL_Haptic *haptic, int gain)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
+int SDL_XINPUT_HapticSetAutocenter(SDL_Haptic *haptic, int autocenter)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticPause(SDL_Haptic * haptic)
+int SDL_XINPUT_HapticPause(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticUnpause(SDL_Haptic * haptic)
+int SDL_XINPUT_HapticUnpause(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
 
-int
-SDL_XINPUT_HapticStopAll(SDL_Haptic * haptic)
+int SDL_XINPUT_HapticStopAll(SDL_Haptic *haptic)
 {
     return SDL_Unsupported();
 }
