@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -23,13 +23,14 @@
 #ifdef SDL_JOYSTICK_USBHID
 
 /*
- * Joystick driver for the uhid(4) interface found in OpenBSD,
+ * Joystick driver for the uhid(4) / ujoy(4) interface found in OpenBSD,
  * NetBSD and FreeBSD.
  *
  * Maintainer: <vedge at csoft.org>
  */
 
 #include <sys/param.h>
+#include <sys/stat.h>
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -62,10 +63,9 @@
 #include <osreldate.h>
 #if __FreeBSD_kernel_version > 800063
 #include <dev/usb/usb_ioctl.h>
-#endif
-#include <sys/joystick.h>
 #elif defined(__DragonFly__)
 #include <bus/u4b/usb_ioctl.h>
+#endif
 #include <sys/joystick.h>
 #endif
 
@@ -76,31 +76,35 @@
 #include "SDL_joystick.h"
 #include "../SDL_sysjoystick.h"
 #include "../SDL_joystick_c.h"
+#include "../hidapi/SDL_hidapijoystick_c.h"
 
-#define MAX_UHID_JOYS   64
-#define MAX_JOY_JOYS    2
-#define MAX_JOYS    (MAX_UHID_JOYS + MAX_JOY_JOYS)
+#if defined(__FREEBSD__) || SDL_HAVE_MACHINE_JOYSTICK_H || defined(__FreeBSD_kernel__) || defined(__DragonFly_)
+#define SUPPORT_JOY_GAMEPORT
+#endif
+
+#define MAX_UHID_JOYS 64
+#define MAX_JOY_JOYS  2
+#define MAX_JOYS      (MAX_UHID_JOYS + MAX_JOY_JOYS)
 
 #ifdef __OpenBSD__
 
-#define HUG_DPAD_UP         0x90
-#define HUG_DPAD_DOWN       0x91
-#define HUG_DPAD_RIGHT      0x92
-#define HUG_DPAD_LEFT       0x93
+#define HUG_DPAD_UP    0x90
+#define HUG_DPAD_DOWN  0x91
+#define HUG_DPAD_RIGHT 0x92
+#define HUG_DPAD_LEFT  0x93
 
-#define HAT_CENTERED        0x00
-#define HAT_UP              0x01
-#define HAT_RIGHT           0x02
-#define HAT_DOWN            0x04
-#define HAT_LEFT            0x08
-#define HAT_RIGHTUP         (HAT_RIGHT|HAT_UP)
-#define HAT_RIGHTDOWN       (HAT_RIGHT|HAT_DOWN)
-#define HAT_LEFTUP          (HAT_LEFT|HAT_UP)
-#define HAT_LEFTDOWN        (HAT_LEFT|HAT_DOWN)
+#define HAT_CENTERED  0x00
+#define HAT_UP        0x01
+#define HAT_RIGHT     0x02
+#define HAT_DOWN      0x04
+#define HAT_LEFT      0x08
+#define HAT_RIGHTUP   (HAT_RIGHT | HAT_UP)
+#define HAT_RIGHTDOWN (HAT_RIGHT | HAT_DOWN)
+#define HAT_LEFTUP    (HAT_LEFT | HAT_UP)
+#define HAT_LEFTDOWN  (HAT_LEFT | HAT_DOWN)
 
 /* calculate the value from the state of the dpad */
-int
-dpad_to_sdl(Sint32 *dpad)
+int dpad_to_sdl(Sint32 *dpad)
 {
     if (dpad[2]) {
         if (dpad[0])
@@ -135,8 +139,8 @@ struct report
 #else
     struct usb_ctl_report *buf; /* Buffer */
 #endif
-    size_t size;                /* Buffer size */
-    int rid;                    /* Report ID */
+    size_t size; /* Buffer size */
+    int rid;     /* Report ID */
     enum
     {
         SREPORT_UNINIT,
@@ -151,9 +155,9 @@ static struct
     hid_kind_t kind;
     const char *name;
 } const repinfo[] = {
-    {UHID_INPUT_REPORT, hid_input, "input"},
-    {UHID_OUTPUT_REPORT, hid_output, "output"},
-    {UHID_FEATURE_REPORT, hid_feature, "feature"}
+    { UHID_INPUT_REPORT, hid_input, "input" },
+    { UHID_OUTPUT_REPORT, hid_output, "output" },
+    { UHID_FEATURE_REPORT, hid_feature, "feature" }
 };
 
 enum
@@ -179,19 +183,34 @@ enum
 struct joystick_hwdata
 {
     int fd;
-    char *path;
     enum
     {
-        BSDJOY_UHID,            /* uhid(4) */
-        BSDJOY_JOY              /* joy(4) */
+        BSDJOY_UHID, /* uhid(4) */
+        BSDJOY_JOY   /* joy(4) */
     } type;
+
+    int naxes;
+    int nbuttons;
+    int nhats;
     struct report_desc *repdesc;
     struct report inreport;
     int axis_map[JOYAXE_count]; /* map present JOYAXE_* to 0,1,.. */
 };
 
-static char *joynames[MAX_JOYS];
-static char *joydevnames[MAX_JOYS];
+/* A linked list of available joysticks */
+typedef struct SDL_joylist_item
+{
+    SDL_JoystickID device_instance;
+    char *path; /* "/dev/uhid0" or whatever */
+    char *name; /* "SideWinder 3D Pro" or whatever */
+    SDL_JoystickGUID guid;
+    dev_t devnum;
+    struct SDL_joylist_item *next;
+} SDL_joylist_item;
+
+static SDL_joylist_item *SDL_joylist = NULL;
+static SDL_joylist_item *SDL_joylist_tail = NULL;
+static int numjoysticks = 0;
 
 static int report_alloc(struct report *, struct report_desc *, int);
 static void report_free(struct report *);
@@ -207,98 +226,7 @@ static void report_free(struct report *);
 #define REP_BUF_DATA(rep) ((rep)->buf->data)
 #endif
 
-static int numjoysticks = 0;
-
-static int BSD_JoystickOpen(SDL_Joystick *joy, int device_index);
-static void BSD_JoystickClose(SDL_Joystick *joy);
-
-static int
-BSD_JoystickInit(void)
-{
-    char s[16];
-    int i, fd;
-
-    numjoysticks = 0;
-
-    SDL_memset(joynames, 0, sizeof(joynames));
-    SDL_memset(joydevnames, 0, sizeof(joydevnames));
-
-    for (i = 0; i < MAX_UHID_JOYS; i++) {
-        SDL_Joystick nj;
-
-        SDL_snprintf(s, SDL_arraysize(s), "/dev/uhid%d", i);
-
-        joynames[numjoysticks] = SDL_strdup(s);
-
-        if (BSD_JoystickOpen(&nj, numjoysticks) == 0) {
-            BSD_JoystickClose(&nj);
-            numjoysticks++;
-        } else {
-            SDL_free(joynames[numjoysticks]);
-            joynames[numjoysticks] = NULL;
-        }
-    }
-    for (i = 0; i < MAX_JOY_JOYS; i++) {
-        SDL_snprintf(s, SDL_arraysize(s), "/dev/joy%d", i);
-        fd = open(s, O_RDONLY | O_CLOEXEC);
-        if (fd != -1) {
-            joynames[numjoysticks++] = SDL_strdup(s);
-            close(fd);
-        }
-    }
-
-    /* Read the default USB HID usage table. */
-    hid_init(NULL);
-
-    return (numjoysticks);
-}
-
-static int
-BSD_JoystickGetCount(void)
-{
-    return numjoysticks;
-}
-
-static void
-BSD_JoystickDetect(void)
-{
-}
-
-static const char *
-BSD_JoystickGetDeviceName(int device_index)
-{
-    if (joydevnames[device_index] != NULL) {
-        return joydevnames[device_index];
-    }
-    return joynames[device_index];
-}
-
-static const char *
-BSD_JoystickGetDevicePath(int device_index)
-{
-    return joynames[device_index];
-}
-
-static int
-BSD_JoystickGetDevicePlayerIndex(int device_index)
-{
-    return -1;
-}
-
-static void
-BSD_JoystickSetDevicePlayerIndex(int device_index, int player_index)
-{
-}
-
-/* Function to perform the mapping from device index to the instance id for this index */
-static SDL_JoystickID
-BSD_JoystickGetDeviceInstanceID(int device_index)
-{
-    return device_index;
-}
-
-static int
-usage_to_joyaxe(unsigned usage)
+static int usage_to_joyaxe(int usage)
 {
     int joyaxe;
     switch (usage) {
@@ -332,8 +260,341 @@ usage_to_joyaxe(unsigned usage)
     return joyaxe;
 }
 
-static unsigned
-hatval_to_sdl(Sint32 hatval)
+static void FreeJoylistItem(SDL_joylist_item *item)
+{
+    SDL_free(item->path);
+    SDL_free(item->name);
+    SDL_free(item);
+}
+
+static void FreeHwData(struct joystick_hwdata *hw)
+{
+    if (hw->type == BSDJOY_UHID) {
+        report_free(&hw->inreport);
+
+        if (hw->repdesc) {
+            hid_dispose_report_desc(hw->repdesc);
+        }
+    }
+    close(hw->fd);
+    SDL_free(hw);
+}
+
+static struct joystick_hwdata *
+CreateHwData(const char *path)
+{
+    struct joystick_hwdata *hw;
+    struct hid_item hitem;
+    struct hid_data *hdata;
+    struct report *rep = NULL;
+    int fd;
+    int i;
+
+    fd = open(path, O_RDONLY | O_CLOEXEC);
+    if (fd == -1) {
+        SDL_SetError("%s: %s", path, strerror(errno));
+        return NULL;
+    }
+
+    hw = (struct joystick_hwdata *)
+        SDL_calloc(1, sizeof(struct joystick_hwdata));
+    if (hw == NULL) {
+        close(fd);
+        SDL_OutOfMemory();
+        return NULL;
+    }
+    hw->fd = fd;
+
+#ifdef SUPPORT_JOY_GAMEPORT
+    if (SDL_strncmp(path, "/dev/joy", 8) == 0) {
+        hw->type = BSDJOY_JOY;
+        hw->naxes = 2;
+        hw->nbuttons = 2;
+    } else
+#endif
+    {
+        hw->type = BSDJOY_UHID;
+        {
+            int ax;
+            for (ax = 0; ax < JOYAXE_count; ax++) {
+                hw->axis_map[ax] = -1;
+            }
+        }
+        hw->repdesc = hid_get_report_desc(fd);
+        if (hw->repdesc == NULL) {
+            SDL_SetError("%s: USB_GET_REPORT_DESC: %s", path,
+                         strerror(errno));
+            goto usberr;
+        }
+        rep = &hw->inreport;
+#if defined(__FREEBSD__) && (__FreeBSD_kernel_version > 800063) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
+        rep->rid = hid_get_report_id(fd);
+        if (rep->rid < 0) {
+#else
+        if (ioctl(fd, USB_GET_REPORT_ID, &rep->rid) < 0) {
+#endif
+            rep->rid = -1; /* XXX */
+        }
+        if (report_alloc(rep, hw->repdesc, REPORT_INPUT) < 0) {
+            goto usberr;
+        }
+        if (rep->size <= 0) {
+            SDL_SetError("%s: Input report descriptor has invalid length",
+                         path);
+            goto usberr;
+        }
+#if defined(USBHID_NEW) || (defined(__FREEBSD__) && __FreeBSD_kernel_version >= 500111) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
+        hdata = hid_start_parse(hw->repdesc, 1 << hid_input, rep->rid);
+#else
+        hdata = hid_start_parse(hw->repdesc, 1 << hid_input);
+#endif
+        if (hdata == NULL) {
+            SDL_SetError("%s: Cannot start HID parser", path);
+            goto usberr;
+        }
+        for (i = 0; i < JOYAXE_count; i++) {
+            hw->axis_map[i] = -1;
+        }
+
+        while (hid_get_item(hdata, &hitem) > 0) {
+            switch (hitem.kind) {
+            case hid_input:
+                switch (HID_PAGE(hitem.usage)) {
+                case HUP_GENERIC_DESKTOP:
+                {
+                    int usage = HID_USAGE(hitem.usage);
+                    int joyaxe = usage_to_joyaxe(usage);
+                    if (joyaxe >= 0) {
+                        hw->axis_map[joyaxe] = 1;
+                    } else if (usage == HUG_HAT_SWITCH
+#ifdef __OpenBSD__
+                               || usage == HUG_DPAD_UP
+#endif
+                    ) {
+                        hw->nhats++;
+                    }
+                    break;
+                }
+                case HUP_BUTTON:
+                {
+                    int usage = HID_USAGE(hitem.usage);
+                    if (usage > hw->nbuttons) {
+                        hw->nbuttons = usage;
+                    }
+                } break;
+                default:
+                    break;
+                }
+                break;
+            default:
+                break;
+            }
+        }
+        hid_end_parse(hdata);
+        for (i = 0; i < JOYAXE_count; i++) {
+            if (hw->axis_map[i] > 0) {
+                hw->axis_map[i] = hw->naxes++;
+            }
+        }
+
+        if (hw->naxes == 0 && hw->nbuttons == 0 && hw->nhats == 0) {
+            SDL_SetError("%s: Not a joystick, ignoring", path);
+            goto usberr;
+        }
+    }
+
+    /* The poll blocks the event thread. */
+    fcntl(fd, F_SETFL, O_NONBLOCK);
+#ifdef __NetBSD__
+    /* Flush pending events */
+    if (rep) {
+        while (read(fd, REP_BUF_DATA(rep), rep->size) == rep->size)
+            ;
+    }
+#endif
+
+    return hw;
+
+usberr:
+    FreeHwData(hw);
+    return NULL;
+}
+
+static int MaybeAddDevice(const char *path)
+{
+    struct stat sb;
+    char *name = NULL;
+    SDL_JoystickGUID guid;
+    SDL_joylist_item *item;
+    struct joystick_hwdata *hw;
+
+    if (path == NULL) {
+        return -1;
+    }
+
+    if (stat(path, &sb) == -1) {
+        return -1;
+    }
+
+    /* Check to make sure it's not already in list. */
+    for (item = SDL_joylist; item != NULL; item = item->next) {
+        if (sb.st_rdev == item->devnum) {
+            return -1; /* already have this one */
+        }
+    }
+
+    hw = CreateHwData(path);
+    if (hw == NULL) {
+        return -1;
+    }
+
+    if (hw->type == BSDJOY_JOY) {
+        name = SDL_strdup("Gameport joystick");
+        guid = SDL_CreateJoystickGUIDForName(name);
+    } else {
+#ifdef USB_GET_DEVICEINFO
+        struct usb_device_info di;
+        if (ioctl(hw->fd, USB_GET_DEVICEINFO, &di) != -1) {
+            name = SDL_CreateJoystickName(di.udi_vendorNo, di.udi_productNo, di.udi_vendor, di.udi_product);
+            guid = SDL_CreateJoystickGUID(SDL_HARDWARE_BUS_USB, di.udi_vendorNo, di.udi_productNo, di.udi_releaseNo, name, 0, 0);
+
+#ifdef SDL_JOYSTICK_HIDAPI
+            if (HIDAPI_IsDevicePresent(di.udi_vendorNo, di.udi_productNo, di.udi_releaseNo, name)) {
+                /* The HIDAPI driver is taking care of this device */
+                SDL_free(name);
+                FreeHwData(hw);
+                return -1;
+            }
+#endif
+            if (SDL_ShouldIgnoreJoystick(name, guid)) {
+                SDL_free(name);
+                FreeHwData(hw);
+                return -1;
+            }
+        }
+#endif /* USB_GET_DEVICEINFO */
+    }
+    if (name == NULL) {
+        name = SDL_strdup(path);
+        guid = SDL_CreateJoystickGUIDForName(name);
+    }
+    FreeHwData(hw);
+
+    item = (SDL_joylist_item *)SDL_calloc(1, sizeof(SDL_joylist_item));
+    if (item == NULL) {
+        SDL_free(name);
+        return -1;
+    }
+
+    item->devnum = sb.st_rdev;
+    item->path = SDL_strdup(path);
+    item->name = name;
+    item->guid = guid;
+
+    if ((item->path == NULL) || (item->name == NULL)) {
+        FreeJoylistItem(item);
+        return -1;
+    }
+
+    item->device_instance = SDL_GetNextJoystickInstanceID();
+    if (SDL_joylist_tail == NULL) {
+        SDL_joylist = SDL_joylist_tail = item;
+    } else {
+        SDL_joylist_tail->next = item;
+        SDL_joylist_tail = item;
+    }
+
+    /* Need to increment the joystick count before we post the event */
+    ++numjoysticks;
+
+    SDL_PrivateJoystickAdded(item->device_instance);
+
+    return numjoysticks;
+}
+
+static int BSD_JoystickInit(void)
+{
+    char s[16];
+    int i;
+
+    for (i = 0; i < MAX_UHID_JOYS; i++) {
+#if defined(__OpenBSD__) && (OpenBSD >= 202105)
+        SDL_snprintf(s, SDL_arraysize(s), "/dev/ujoy/%d", i);
+#else
+        SDL_snprintf(s, SDL_arraysize(s), "/dev/uhid%d", i);
+#endif
+        MaybeAddDevice(s);
+    }
+#ifdef SUPPORT_JOY_GAMEPORT
+    for (i = 0; i < MAX_JOY_JOYS; i++) {
+        SDL_snprintf(s, SDL_arraysize(s), "/dev/joy%d", i);
+        MaybeAddDevice(s);
+    }
+#endif /* SUPPORT_JOY_GAMEPORT */
+
+    /* Read the default USB HID usage table. */
+    hid_init(NULL);
+
+    return numjoysticks;
+}
+
+static int BSD_JoystickGetCount(void)
+{
+    return numjoysticks;
+}
+
+static void BSD_JoystickDetect(void)
+{
+}
+
+static SDL_joylist_item *JoystickByDevIndex(int device_index)
+{
+    SDL_joylist_item *item = SDL_joylist;
+
+    if ((device_index < 0) || (device_index >= numjoysticks)) {
+        return NULL;
+    }
+
+    while (device_index > 0) {
+        SDL_assert(item != NULL);
+        device_index--;
+        item = item->next;
+    }
+
+    return item;
+}
+
+static const char *BSD_JoystickGetDeviceName(int device_index)
+{
+    return JoystickByDevIndex(device_index)->name;
+}
+
+static const char *BSD_JoystickGetDevicePath(int device_index)
+{
+    return JoystickByDevIndex(device_index)->path;
+}
+
+static int BSD_JoystickGetDevicePlayerIndex(int device_index)
+{
+    return -1;
+}
+
+static void BSD_JoystickSetDevicePlayerIndex(int device_index, int player_index)
+{
+}
+
+static SDL_JoystickGUID BSD_JoystickGetDeviceGUID(int device_index)
+{
+    return JoystickByDevIndex(device_index)->guid;
+}
+
+/* Function to perform the mapping from device index to the instance id for this index */
+static SDL_JoystickID BSD_JoystickGetDeviceInstanceID(int device_index)
+{
+    return JoystickByDevIndex(device_index)->device_instance;
+}
+
+static unsigned hatval_to_sdl(Sint32 hatval)
 {
     static const unsigned hat_dir_map[8] = {
         SDL_HAT_UP, SDL_HAT_RIGHTUP, SDL_HAT_RIGHT, SDL_HAT_RIGHTDOWN,
@@ -347,201 +608,30 @@ hatval_to_sdl(Sint32 hatval)
     return result;
 }
 
-
-static int
-BSD_JoystickOpen(SDL_Joystick *joy, int device_index)
+static int BSD_JoystickOpen(SDL_Joystick *joy, int device_index)
 {
-    char *path = joynames[device_index];
+    SDL_joylist_item *item = JoystickByDevIndex(device_index);
     struct joystick_hwdata *hw;
-    struct hid_item hitem;
-    struct hid_data *hdata;
-    struct report *rep = NULL;
-#if defined(__NetBSD__)
-    usb_device_descriptor_t udd;
-    struct usb_string_desc usd;
-#endif
-    int fd;
-    int i;
 
-    fd = open(path, O_RDONLY | O_CLOEXEC);
-    if (fd == -1) {
-        return SDL_SetError("%s: %s", path, strerror(errno));
+    if (item == NULL) {
+        return SDL_SetError("No such device");
     }
 
-    joy->instance_id = device_index;
-    hw = (struct joystick_hwdata *)
-        SDL_malloc(sizeof(struct joystick_hwdata));
+    hw = CreateHwData(item->path);
     if (hw == NULL) {
-        close(fd);
-        return SDL_OutOfMemory();
+        return -1;
     }
+
+    joy->instance_id = item->device_instance;
     joy->hwdata = hw;
-    hw->fd = fd;
-    hw->path = SDL_strdup(path);
-    if (!SDL_strncmp(path, "/dev/joy", 8)) {
-        hw->type = BSDJOY_JOY;
-        joy->naxes = 2;
-        joy->nbuttons = 2;
-        joy->nhats = 0;
-        joy->nballs = 0;
-        joydevnames[device_index] = SDL_strdup("Gameport joystick");
-        goto usbend;
-    } else {
-        hw->type = BSDJOY_UHID;
-    }
+    joy->naxes = hw->naxes;
+    joy->nbuttons = hw->nbuttons;
+    joy->nhats = hw->nhats;
 
-    {
-        int ax;
-        for (ax = 0; ax < JOYAXE_count; ax++)
-            hw->axis_map[ax] = -1;
-    }
-    hw->repdesc = hid_get_report_desc(fd);
-    if (hw->repdesc == NULL) {
-        SDL_SetError("%s: USB_GET_REPORT_DESC: %s", hw->path,
-                     strerror(errno));
-        goto usberr;
-    }
-    rep = &hw->inreport;
-#if defined(__FREEBSD__) && (__FreeBSD_kernel_version > 800063) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
-    rep->rid = hid_get_report_id(fd);
-    if (rep->rid < 0) {
-#else
-    if (ioctl(fd, USB_GET_REPORT_ID, &rep->rid) < 0) {
-#endif
-        rep->rid = -1;          /* XXX */
-    }
-#if defined(__NetBSD__)
-    if (ioctl(fd, USB_GET_DEVICE_DESC, &udd) == -1)
-        goto desc_failed;
-
-    /* Get default language */
-    usd.usd_string_index = USB_LANGUAGE_TABLE;
-    usd.usd_language_id = 0;
-    if (ioctl(fd, USB_GET_STRING_DESC, &usd) == -1 || usd.usd_desc.bLength < 4) {
-        usd.usd_language_id = 0;
-    } else {
-        usd.usd_language_id = UGETW(usd.usd_desc.bString[0]);
-    }
-
-    usd.usd_string_index = udd.iProduct;
-    if (ioctl(fd, USB_GET_STRING_DESC, &usd) == 0) {
-        char str[128];
-        char *new_name = NULL;
-        int i;
-        for (i = 0; i < (usd.usd_desc.bLength >> 1) - 1 && i < sizeof(str) - 1; i++) {
-            str[i] = UGETW(usd.usd_desc.bString[i]);
-        }
-        str[i] = '\0';
-        SDL_asprintf(&new_name, "%s @ %s", str, path);
-        if (new_name != NULL) {
-            SDL_free(joydevnames[numjoysticks]);
-            joydevnames[numjoysticks] = new_name;
-        }
-    }
-desc_failed:
-#endif
-    if (report_alloc(rep, hw->repdesc, REPORT_INPUT) < 0) {
-        goto usberr;
-    }
-    if (rep->size <= 0) {
-        SDL_SetError("%s: Input report descriptor has invalid length",
-                     hw->path);
-        goto usberr;
-    }
-#if defined(USBHID_NEW) || (defined(__FREEBSD__) && __FreeBSD_kernel_version >= 500111) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
-    hdata = hid_start_parse(hw->repdesc, 1 << hid_input, rep->rid);
-#else
-    hdata = hid_start_parse(hw->repdesc, 1 << hid_input);
-#endif
-    if (hdata == NULL) {
-        SDL_SetError("%s: Cannot start HID parser", hw->path);
-        goto usberr;
-    }
-    joy->naxes = 0;
-    joy->nbuttons = 0;
-    joy->nhats = 0;
-    joy->nballs = 0;
-    for (i = 0; i < JOYAXE_count; i++)
-        hw->axis_map[i] = -1;
-
-    while (hid_get_item(hdata, &hitem) > 0) {
-        char *sp;
-        const char *s;
-
-        switch (hitem.kind) {
-        case hid_collection:
-            switch (HID_PAGE(hitem.usage)) {
-            case HUP_GENERIC_DESKTOP:
-                switch (HID_USAGE(hitem.usage)) {
-                case HUG_JOYSTICK:
-                case HUG_GAME_PAD:
-                    s = hid_usage_in_page(hitem.usage);
-                    sp = SDL_malloc(SDL_strlen(s) + 5);
-                    SDL_snprintf(sp, SDL_strlen(s) + 5, "%s (%d)",
-                                 s, device_index);
-                    joydevnames[device_index] = sp;
-                }
-            }
-            break;
-        case hid_input:
-            switch (HID_PAGE(hitem.usage)) {
-            case HUP_GENERIC_DESKTOP:
-                {
-                    unsigned usage = HID_USAGE(hitem.usage);
-                    int joyaxe = usage_to_joyaxe(usage);
-                    if (joyaxe >= 0) {
-                        hw->axis_map[joyaxe] = 1;
-                    } else if (usage == HUG_HAT_SWITCH
-#ifdef __OpenBSD__
-                               || usage == HUG_DPAD_UP
-#endif
-                               ) {
-                        joy->nhats++;
-                    }
-                    break;
-                }
-            case HUP_BUTTON:
-                joy->nbuttons++;
-                break;
-            default:
-                break;
-            }
-            break;
-        default:
-            break;
-        }
-    }
-    hid_end_parse(hdata);
-    for (i = 0; i < JOYAXE_count; i++)
-        if (hw->axis_map[i] > 0)
-            hw->axis_map[i] = joy->naxes++;
-
-    if (joy->naxes == 0 && joy->nbuttons == 0 && joy->nhats == 0 && joy->nballs == 0) {
-        SDL_SetError("%s: Not a joystick, ignoring", hw->path);
-        goto usberr;
-    }
-
-  usbend:
-    /* The poll blocks the event thread. */
-    fcntl(fd, F_SETFL, O_NONBLOCK);
-#ifdef __NetBSD__
-    /* Flush pending events */
-    if (rep) {
-        while (read(joy->hwdata->fd, REP_BUF_DATA(rep), rep->size) == rep->size)
-            ;
-    }
-#endif
-
-    return (0);
-  usberr:
-    close(hw->fd);
-    SDL_free(hw->path);
-    SDL_free(hw);
-    return (-1);
+    return 0;
 }
 
-static void
-BSD_JoystickUpdate(SDL_Joystick *joy)
+static void BSD_JoystickUpdate(SDL_Joystick *joy)
 {
     struct hid_item hitem;
     struct hid_data *hdata;
@@ -549,15 +639,15 @@ BSD_JoystickUpdate(SDL_Joystick *joy)
     int nbutton, naxe = -1;
     Sint32 v;
 #ifdef __OpenBSD__
-    Sint32 dpad[4] = {0, 0, 0, 0};
+    Sint32 dpad[4] = { 0, 0, 0, 0 };
 #endif
 
-#if defined(__FREEBSD__) || SDL_HAVE_MACHINE_JOYSTICK_H || defined(__FreeBSD_kernel__) || defined(__DragonFly_)
+#ifdef SUPPORT_JOY_GAMEPORT
     struct joystick gameport;
     static int x, y, xmin = 0xffff, ymin = 0xffff, xmax = 0, ymax = 0;
 
     if (joy->hwdata->type == BSDJOY_JOY) {
-        while (read(joy->hwdata->fd, &gameport, sizeof gameport) == sizeof gameport) {
+        while (read(joy->hwdata->fd, &gameport, sizeof(gameport)) == sizeof(gameport)) {
             if (SDL_abs(x - gameport.x) > 8) {
                 x = gameport.x;
                 if (x < xmin) {
@@ -570,9 +660,7 @@ BSD_JoystickUpdate(SDL_Joystick *joy)
                     xmin--;
                     xmax++;
                 }
-                v = (Sint32) x;
-                v -= (xmax + xmin + 1) / 2;
-                v *= 32768 / ((xmax - xmin + 1) / 2);
+                v = (((SDL_JOYSTICK_AXIS_MAX - SDL_JOYSTICK_AXIS_MIN) * ((Sint32)x - xmin)) / (xmax - xmin)) + SDL_JOYSTICK_AXIS_MIN;
                 SDL_PrivateJoystickAxis(joy, 0, v);
             }
             if (SDL_abs(y - gameport.y) > 8) {
@@ -587,9 +675,7 @@ BSD_JoystickUpdate(SDL_Joystick *joy)
                     ymin--;
                     ymax++;
                 }
-                v = (Sint32) y;
-                v -= (ymax + ymin + 1) / 2;
-                v *= 32768 / ((ymax - ymin + 1) / 2);
+                v = (((SDL_JOYSTICK_AXIS_MAX - SDL_JOYSTICK_AXIS_MIN) * ((Sint32)y - ymin)) / (ymax - ymin)) + SDL_JOYSTICK_AXIS_MIN;
                 SDL_PrivateJoystickAxis(joy, 1, v);
             }
             SDL_PrivateJoystickButton(joy, 0, gameport.b1);
@@ -597,7 +683,7 @@ BSD_JoystickUpdate(SDL_Joystick *joy)
         }
         return;
     }
-#endif /* defined(__FREEBSD__) || SDL_HAVE_MACHINE_JOYSTICK_H */
+#endif /* SUPPORT_JOY_GAMEPORT */
 
     rep = &joy->hwdata->inreport;
 
@@ -612,54 +698,47 @@ BSD_JoystickUpdate(SDL_Joystick *joy)
             continue;
         }
 
-        for (nbutton = 0; hid_get_item(hdata, &hitem) > 0;) {
+        while (hid_get_item(hdata, &hitem) > 0) {
             switch (hitem.kind) {
             case hid_input:
                 switch (HID_PAGE(hitem.usage)) {
                 case HUP_GENERIC_DESKTOP:
-                    {
-                        unsigned usage = HID_USAGE(hitem.usage);
-                        int joyaxe = usage_to_joyaxe(usage);
-                        if (joyaxe >= 0) {
-                            naxe = joy->hwdata->axis_map[joyaxe];
-                            /* scaleaxe */
-                            v = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
-                            v -= (hitem.logical_maximum +
-                                  hitem.logical_minimum + 1) / 2;
-                            v *= 32768 /
-                                ((hitem.logical_maximum -
-                                  hitem.logical_minimum + 1) / 2);
-                            SDL_PrivateJoystickAxis(joy, naxe, v);
-                        } else if (usage == HUG_HAT_SWITCH) {
-                            v = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
-                            SDL_PrivateJoystickHat(joy, 0,
-                                                   hatval_to_sdl(v) -
+                {
+                    int usage = HID_USAGE(hitem.usage);
+                    int joyaxe = usage_to_joyaxe(usage);
+                    if (joyaxe >= 0) {
+                        naxe = joy->hwdata->axis_map[joyaxe];
+                        /* scaleaxe */
+                        v = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                        v = (((SDL_JOYSTICK_AXIS_MAX - SDL_JOYSTICK_AXIS_MIN) * (v - hitem.logical_minimum)) / (hitem.logical_maximum - hitem.logical_minimum)) + SDL_JOYSTICK_AXIS_MIN;
+                        SDL_PrivateJoystickAxis(joy, naxe, v);
+                    } else if (usage == HUG_HAT_SWITCH) {
+                        v = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                        SDL_PrivateJoystickHat(joy, 0,
+                                               hatval_to_sdl(v) -
                                                    hitem.logical_minimum);
-                        }
-#ifdef __OpenBSD__
-                        else if (usage == HUG_DPAD_UP) {
-                            dpad[0] = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
-                            SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
-                        }
-                        else if (usage == HUG_DPAD_DOWN) {
-                            dpad[1] = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
-                            SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
-                        }
-                        else if (usage == HUG_DPAD_RIGHT) {
-                            dpad[2] = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
-                            SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
-                        }
-                        else if (usage == HUG_DPAD_LEFT) {
-                            dpad[3] = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
-                            SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
-                        }
-#endif
-                        break;
                     }
+#ifdef __OpenBSD__
+                    else if (usage == HUG_DPAD_UP) {
+                        dpad[0] = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                        SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
+                    } else if (usage == HUG_DPAD_DOWN) {
+                        dpad[1] = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                        SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
+                    } else if (usage == HUG_DPAD_RIGHT) {
+                        dpad[2] = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                        SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
+                    } else if (usage == HUG_DPAD_LEFT) {
+                        dpad[3] = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                        SDL_PrivateJoystickHat(joy, 0, dpad_to_sdl(dpad));
+                    }
+#endif
+                    break;
+                }
                 case HUP_BUTTON:
-                    v = (Sint32) hid_get_data(REP_BUF_DATA(rep), &hitem);
+                    v = (Sint32)hid_get_data(REP_BUF_DATA(rep), &hitem);
+                    nbutton = HID_USAGE(hitem.usage) - 1; /* SDL buttons are zero-based */
                     SDL_PrivateJoystickButton(joy, nbutton, v);
-                    nbutton++;
                     break;
                 default:
                     continue;
@@ -674,65 +753,51 @@ BSD_JoystickUpdate(SDL_Joystick *joy)
 }
 
 /* Function to close a joystick after use */
-static void
-BSD_JoystickClose(SDL_Joystick *joy)
+static void BSD_JoystickClose(SDL_Joystick *joy)
 {
-    if (SDL_strncmp(joy->hwdata->path, "/dev/joy", 8)) {
-        report_free(&joy->hwdata->inreport);
-        hid_dispose_report_desc(joy->hwdata->repdesc);
+    if (joy->hwdata) {
+        FreeHwData(joy->hwdata);
+        joy->hwdata = NULL;
     }
-    close(joy->hwdata->fd);
-    SDL_free(joy->hwdata->path);
-    SDL_free(joy->hwdata);
 }
 
-static void
-BSD_JoystickQuit(void)
+static void BSD_JoystickQuit(void)
 {
-    int i;
+    SDL_joylist_item *item = NULL;
+    SDL_joylist_item *next = NULL;
 
-    for (i = 0; i < MAX_JOYS; i++) {
-        SDL_free(joynames[i]);
-        SDL_free(joydevnames[i]);
+    for (item = SDL_joylist; item; item = next) {
+        next = item->next;
+        FreeJoylistItem(item);
     }
 
-    return;
+    SDL_joylist = SDL_joylist_tail = NULL;
+
+    numjoysticks = 0;
 }
 
-static SDL_JoystickGUID
-BSD_JoystickGetDeviceGUID( int device_index )
-{
-    SDL_JoystickGUID guid;
-    /* the GUID is just the first 16 chars of the name for now */
-    const char *name = BSD_JoystickGetDeviceName( device_index );
-    SDL_zero( guid );
-    SDL_memcpy( &guid, name, SDL_min( sizeof(guid), SDL_strlen( name ) ) );
-    return guid;
-}
-
-static int
-report_alloc(struct report *r, struct report_desc *rd, int repind)
+static int report_alloc(struct report *r, struct report_desc *rd, int repind)
 {
     int len;
 
 #ifdef __DragonFly__
     len = hid_report_size(rd, repinfo[repind].kind, r->rid);
 #elif __FREEBSD__
-# if (__FreeBSD_kernel_version >= 460000) || defined(__FreeBSD_kernel__)
-#  if (__FreeBSD_kernel_version <= 500111)
+#if (__FreeBSD_kernel_version >= 460000) || defined(__FreeBSD_kernel__)
+#if (__FreeBSD_kernel_version <= 500111)
     len = hid_report_size(rd, r->rid, repinfo[repind].kind);
-#  else
-    len = hid_report_size(rd, repinfo[repind].kind, r->rid);
-#  endif
-# else
-    len = hid_report_size(rd, repinfo[repind].kind, &r->rid);
-# endif
 #else
-# ifdef USBHID_NEW
     len = hid_report_size(rd, repinfo[repind].kind, r->rid);
-# else
+#endif
+#else
     len = hid_report_size(rd, repinfo[repind].kind, &r->rid);
-# endif
+#endif
+#else
+#ifdef USBHID_NEW
+    len = hid_report_size(rd, repinfo[repind].kind, r->rid);
+#else
+    len = hid_report_size(rd, repinfo[repind].kind, &r->rid);
+#endif
 #endif
 
     if (len < 0) {
@@ -758,57 +823,48 @@ report_alloc(struct report *r, struct report_desc *rd, int repind)
     return 0;
 }
 
-static void
-report_free(struct report *r)
+static void report_free(struct report *r)
 {
     SDL_free(r->buf);
     r->status = SREPORT_UNINIT;
 }
 
-static int
-BSD_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble)
+static int BSD_JoystickRumble(SDL_Joystick *joystick, Uint16 low_frequency_rumble, Uint16 high_frequency_rumble)
 {
     return SDL_Unsupported();
 }
 
-static int
-BSD_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble)
+static int BSD_JoystickRumbleTriggers(SDL_Joystick *joystick, Uint16 left_rumble, Uint16 right_rumble)
 {
     return SDL_Unsupported();
 }
 
-static SDL_bool
-BSD_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
+static SDL_bool BSD_JoystickGetGamepadMapping(int device_index, SDL_GamepadMapping *out)
 {
     return SDL_FALSE;
 }
 
-static Uint32
-BSD_JoystickGetCapabilities(SDL_Joystick *joystick)
+static Uint32 BSD_JoystickGetCapabilities(SDL_Joystick *joystick)
 {
     return 0;
 }
 
-static int
-BSD_JoystickSetLED(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue)
+static int BSD_JoystickSetLED(SDL_Joystick *joystick, Uint8 red, Uint8 green, Uint8 blue)
 {
     return SDL_Unsupported();
 }
 
-static int
-BSD_JoystickSendEffect(SDL_Joystick *joystick, const void *data, int size)
+static int BSD_JoystickSendEffect(SDL_Joystick *joystick, const void *data, int size)
 {
     return SDL_Unsupported();
 }
 
-static int
-BSD_JoystickSetSensorsEnabled(SDL_Joystick *joystick, SDL_bool enabled)
+static int BSD_JoystickSetSensorsEnabled(SDL_Joystick *joystick, SDL_bool enabled)
 {
     return SDL_Unsupported();
 }
 
-SDL_JoystickDriver SDL_BSD_JoystickDriver =
-{
+SDL_JoystickDriver SDL_BSD_JoystickDriver = {
     BSD_JoystickInit,
     BSD_JoystickGetCount,
     BSD_JoystickDetect,
