@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -23,9 +23,9 @@
 
 #if SDL_VIDEO_DRIVER_RPI
 
-#include "../../events/SDL_sysevents.h"
 #include "../../events/SDL_events_c.h"
 #include "../../events/SDL_keyboard_c.h"
+#include "../SDL_sysvideo.h"
 #include "SDL_rpivideo.h"
 #include "SDL_rpievents_c.h"
 
@@ -38,8 +38,6 @@ void RPI_PumpEvents(_THIS)
 #ifdef SDL_INPUT_LINUXEV
     SDL_EVDEV_Poll();
 #endif
-    
 }
 
 #endif /* SDL_VIDEO_DRIVER_RPI */
-
