@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -35,18 +35,18 @@
 
 #include <imm.h>
 
-#define MAX_CANDLIST    10
-#define MAX_CANDLENGTH  256
-#define MAX_CANDSIZE    (sizeof(WCHAR) * MAX_CANDLIST * MAX_CANDLENGTH)
+#define MAX_CANDLIST   10
+#define MAX_CANDLENGTH 256
+#define MAX_CANDSIZE   (sizeof(WCHAR) * MAX_CANDLIST * MAX_CANDLENGTH)
 
 #include "SDL_windowsclipboard.h"
 #include "SDL_windowsevents.h"
+#include "SDL_windowsopengl.h"
 
 #if !defined(__XBOXONE__) && !defined(__XBOXSERIES__)
 #include "SDL_windowskeyboard.h"
 #include "SDL_windowsmodes.h"
 #include "SDL_windowsmouse.h"
-#include "SDL_windowsopengl.h"
 #include "SDL_windowsopengles.h"
 #endif
 
@@ -54,11 +54,10 @@
 #include "SDL_events.h"
 #include "SDL_loadso.h"
 
-
 #if WINVER < 0x0601
 /* Touch input definitions */
-#define TWF_FINETOUCH   1
-#define TWF_WANTPALM    2
+#define TWF_FINETOUCH 1
+#define TWF_WANTPALM  2
 
 #define TOUCHEVENTF_MOVE 0x0001
 #define TOUCHEVENTF_DOWN 0x0002
@@ -66,78 +65,78 @@
 
 DECLARE_HANDLE(HTOUCHINPUT);
 
-typedef struct _TOUCHINPUT {
-    LONG      x;
-    LONG      y;
-    HANDLE    hSource;
-    DWORD     dwID;
-    DWORD     dwFlags;
-    DWORD     dwMask;
-    DWORD     dwTime;
+typedef struct _TOUCHINPUT
+{
+    LONG x;
+    LONG y;
+    HANDLE hSource;
+    DWORD dwID;
+    DWORD dwFlags;
+    DWORD dwMask;
+    DWORD dwTime;
     ULONG_PTR dwExtraInfo;
-    DWORD     cxContact;
-    DWORD     cyContact;
+    DWORD cxContact;
+    DWORD cyContact;
 } TOUCHINPUT, *PTOUCHINPUT;
 
-
 /* More-robust display information in Vista... */
 /* This is a huge amount of data to be stuffing into three API calls. :( */
 typedef struct DISPLAYCONFIG_PATH_SOURCE_INFO
 {
-    LUID    adapterId;
-    UINT32  id;
+    LUID adapterId;
+    UINT32 id;
     union
     {
         UINT32 modeInfoIdx;
         struct
         {
-            UINT32 cloneGroupId       : 16;
-            UINT32 sourceModeInfoIdx  : 16;
+            UINT32 cloneGroupId : 16;
+            UINT32 sourceModeInfoIdx : 16;
         } DUMMYSTRUCTNAME;
     } DUMMYUNIONNAME;
 
-    UINT32  statusFlags;
+    UINT32 statusFlags;
 } DISPLAYCONFIG_PATH_SOURCE_INFO;
 
 typedef struct DISPLAYCONFIG_RATIONAL
 {
-    UINT32    Numerator;
-    UINT32    Denominator;
+    UINT32 Numerator;
+    UINT32 Denominator;
 } DISPLAYCONFIG_RATIONAL;
 
 typedef struct DISPLAYCONFIG_PATH_TARGET_INFO
 {
-    LUID                                    adapterId;
-    UINT32                                  id;
+    LUID adapterId;
+    UINT32 id;
     union
     {
-        UINT32                                  modeInfoIdx;
+        UINT32 modeInfoIdx;
         struct
         {
             UINT32 desktopModeInfoIdx : 16;
-            UINT32 targetModeInfoIdx  : 16;
+            UINT32 targetModeInfoIdx : 16;
         } DUMMYSTRUCTNAME;
     } DUMMYUNIONNAME;
-    UINT32 /*DISPLAYCONFIG_VIDEO_OUTPUT_TECHNOLOGY*/   outputTechnology;
-    UINT32 /*DISPLAYCONFIG_ROTATION*/                  rotation;
-    UINT32 /*DISPLAYCONFIG_SCALING*/                   scaling;
-    DISPLAYCONFIG_RATIONAL                  refreshRate;
-    UINT32 /*DISPLAYCONFIG_SCANLINE_ORDERING*/         scanLineOrdering;
-    BOOL                                    targetAvailable;
-    UINT32                                  statusFlags;
+    UINT32 /*DISPLAYCONFIG_VIDEO_OUTPUT_TECHNOLOGY*/ outputTechnology;
+    UINT32 /*DISPLAYCONFIG_ROTATION*/ rotation;
+    UINT32 /*DISPLAYCONFIG_SCALING*/ scaling;
+    DISPLAYCONFIG_RATIONAL refreshRate;
+    UINT32 /*DISPLAYCONFIG_SCANLINE_ORDERING*/ scanLineOrdering;
+    BOOL targetAvailable;
+    UINT32 statusFlags;
 } DISPLAYCONFIG_PATH_TARGET_INFO;
 
 typedef struct DISPLAYCONFIG_PATH_INFO
 {
-    DISPLAYCONFIG_PATH_SOURCE_INFO  sourceInfo;
-    DISPLAYCONFIG_PATH_TARGET_INFO  targetInfo;
-    UINT32                          flags;
+    DISPLAYCONFIG_PATH_SOURCE_INFO sourceInfo;
+    DISPLAYCONFIG_PATH_TARGET_INFO targetInfo;
+    UINT32 flags;
 } DISPLAYCONFIG_PATH_INFO;
 
 typedef enum
 {
-    DISPLAYCONFIG_MODE_INFO_TYPE_SOURCE        = 1,
-    DISPLAYCONFIG_MODE_INFO_TYPE_TARGET        = 2,
+    DISPLAYCONFIG_MODE_INFO_TYPE_SOURCE = 1,
+    DISPLAYCONFIG_MODE_INFO_TYPE_TARGET = 2,
     DISPLAYCONFIG_MODE_INFO_TYPE_DESKTOP_IMAGE = 3,
     DISPLAYCONFIG_MODE_INFO_TYPE_FORCE_UINT32 = 0xFFFFFFFF
 } DISPLAYCONFIG_MODE_INFO_TYPE;
@@ -150,11 +149,11 @@ typedef struct DISPLAYCONFIG_2DREGION
 
 typedef struct DISPLAYCONFIG_VIDEO_SIGNAL_INFO
 {
-    UINT64                          pixelRate;
-    DISPLAYCONFIG_RATIONAL          hSyncFreq;
-    DISPLAYCONFIG_RATIONAL          vSyncFreq;
-    DISPLAYCONFIG_2DREGION          activeSize;
-    DISPLAYCONFIG_2DREGION          totalSize;
+    UINT64 pixelRate;
+    DISPLAYCONFIG_RATIONAL hSyncFreq;
+    DISPLAYCONFIG_RATIONAL vSyncFreq;
+    DISPLAYCONFIG_2DREGION activeSize;
+    DISPLAYCONFIG_2DREGION totalSize;
 
     union
     {
@@ -177,15 +176,15 @@ typedef struct DISPLAYCONFIG_VIDEO_SIGNAL_INFO
 
 typedef struct DISPLAYCONFIG_SOURCE_MODE
 {
-    UINT32                      width;
-    UINT32                      height;
-    UINT32 /*DISPLAYCONFIG_PIXELFORMAT*/   pixelFormat;
-    POINTL                      position;
+    UINT32 width;
+    UINT32 height;
+    UINT32 /*DISPLAYCONFIG_PIXELFORMAT*/ pixelFormat;
+    POINTL position;
 } DISPLAYCONFIG_SOURCE_MODE;
 
 typedef struct DISPLAYCONFIG_TARGET_MODE
 {
-    DISPLAYCONFIG_VIDEO_SIGNAL_INFO   targetVideoSignalInfo;
+    DISPLAYCONFIG_VIDEO_SIGNAL_INFO targetVideoSignalInfo;
 } DISPLAYCONFIG_TARGET_MODE;
 
 typedef struct DISPLAYCONFIG_DESKTOP_IMAGE_INFO
@@ -197,54 +196,54 @@ typedef struct DISPLAYCONFIG_DESKTOP_IMAGE_INFO
 
 typedef struct DISPLAYCONFIG_MODE_INFO
 {
-    DISPLAYCONFIG_MODE_INFO_TYPE    infoType;
-    UINT32                          id;
-    LUID                            adapterId;
+    DISPLAYCONFIG_MODE_INFO_TYPE infoType;
+    UINT32 id;
+    LUID adapterId;
     union
     {
-        DISPLAYCONFIG_TARGET_MODE   targetMode;
-        DISPLAYCONFIG_SOURCE_MODE   sourceMode;
-        DISPLAYCONFIG_DESKTOP_IMAGE_INFO    desktopImageInfo;
+        DISPLAYCONFIG_TARGET_MODE targetMode;
+        DISPLAYCONFIG_SOURCE_MODE sourceMode;
+        DISPLAYCONFIG_DESKTOP_IMAGE_INFO desktopImageInfo;
     } DUMMYUNIONNAME;
 } DISPLAYCONFIG_MODE_INFO;
 
 typedef enum DISPLAYCONFIG_TOPOLOGY_ID
 {
-      DISPLAYCONFIG_TOPOLOGY_INTERNAL       = 0x00000001,
-      DISPLAYCONFIG_TOPOLOGY_CLONE          = 0x00000002,
-      DISPLAYCONFIG_TOPOLOGY_EXTEND         = 0x00000004,
-      DISPLAYCONFIG_TOPOLOGY_EXTERNAL       = 0x00000008,
-      DISPLAYCONFIG_TOPOLOGY_FORCE_UINT32   = 0xFFFFFFFF
+    DISPLAYCONFIG_TOPOLOGY_INTERNAL = 0x00000001,
+    DISPLAYCONFIG_TOPOLOGY_CLONE = 0x00000002,
+    DISPLAYCONFIG_TOPOLOGY_EXTEND = 0x00000004,
+    DISPLAYCONFIG_TOPOLOGY_EXTERNAL = 0x00000008,
+    DISPLAYCONFIG_TOPOLOGY_FORCE_UINT32 = 0xFFFFFFFF
 } DISPLAYCONFIG_TOPOLOGY_ID;
 
 typedef enum
 {
-      DISPLAYCONFIG_DEVICE_INFO_GET_SOURCE_NAME                 = 1,
-      DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_NAME                 = 2,
-      DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_PREFERRED_MODE       = 3,
-      DISPLAYCONFIG_DEVICE_INFO_GET_ADAPTER_NAME                = 4,
-      DISPLAYCONFIG_DEVICE_INFO_SET_TARGET_PERSISTENCE          = 5,
-      DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_BASE_TYPE            = 6,
-      DISPLAYCONFIG_DEVICE_INFO_GET_SUPPORT_VIRTUAL_RESOLUTION  = 7,
-      DISPLAYCONFIG_DEVICE_INFO_SET_SUPPORT_VIRTUAL_RESOLUTION  = 8,
-      DISPLAYCONFIG_DEVICE_INFO_GET_ADVANCED_COLOR_INFO         = 9,
-      DISPLAYCONFIG_DEVICE_INFO_SET_ADVANCED_COLOR_STATE        = 10,
-      DISPLAYCONFIG_DEVICE_INFO_GET_SDR_WHITE_LEVEL             = 11,
-      DISPLAYCONFIG_DEVICE_INFO_FORCE_UINT32                = 0xFFFFFFFF
+    DISPLAYCONFIG_DEVICE_INFO_GET_SOURCE_NAME = 1,
+    DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_NAME = 2,
+    DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_PREFERRED_MODE = 3,
+    DISPLAYCONFIG_DEVICE_INFO_GET_ADAPTER_NAME = 4,
+    DISPLAYCONFIG_DEVICE_INFO_SET_TARGET_PERSISTENCE = 5,
+    DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_BASE_TYPE = 6,
+    DISPLAYCONFIG_DEVICE_INFO_GET_SUPPORT_VIRTUAL_RESOLUTION = 7,
+    DISPLAYCONFIG_DEVICE_INFO_SET_SUPPORT_VIRTUAL_RESOLUTION = 8,
+    DISPLAYCONFIG_DEVICE_INFO_GET_ADVANCED_COLOR_INFO = 9,
+    DISPLAYCONFIG_DEVICE_INFO_SET_ADVANCED_COLOR_STATE = 10,
+    DISPLAYCONFIG_DEVICE_INFO_GET_SDR_WHITE_LEVEL = 11,
+    DISPLAYCONFIG_DEVICE_INFO_FORCE_UINT32 = 0xFFFFFFFF
 } DISPLAYCONFIG_DEVICE_INFO_TYPE;
 
 typedef struct DISPLAYCONFIG_DEVICE_INFO_HEADER
 {
-    DISPLAYCONFIG_DEVICE_INFO_TYPE  type;
-    UINT32                          size;
-    LUID                            adapterId;
-    UINT32                          id;
+    DISPLAYCONFIG_DEVICE_INFO_TYPE type;
+    UINT32 size;
+    LUID adapterId;
+    UINT32 id;
 } DISPLAYCONFIG_DEVICE_INFO_HEADER;
 
 typedef struct DISPLAYCONFIG_SOURCE_DEVICE_NAME
 {
-    DISPLAYCONFIG_DEVICE_INFO_HEADER            header;
-    WCHAR                                       viewGdiDeviceName[CCHDEVICENAME];
+    DISPLAYCONFIG_DEVICE_INFO_HEADER header;
+    WCHAR viewGdiDeviceName[CCHDEVICENAME];
 } DISPLAYCONFIG_SOURCE_DEVICE_NAME;
 
 typedef struct DISPLAYCONFIG_TARGET_DEVICE_NAME_FLAGS
@@ -253,41 +252,43 @@ typedef struct DISPLAYCONFIG_TARGET_DEVICE_NAME_FLAGS
     {
         struct
         {
-            UINT32  friendlyNameFromEdid : 1;
-            UINT32  friendlyNameForced : 1;
-            UINT32  edidIdsValid : 1;
-            UINT32  reserved : 29;
+            UINT32 friendlyNameFromEdid : 1;
+            UINT32 friendlyNameForced : 1;
+            UINT32 edidIdsValid : 1;
+            UINT32 reserved : 29;
         } DUMMYSTRUCTNAME;
-        UINT32  value;
+        UINT32 value;
     } DUMMYUNIONNAME;
 } DISPLAYCONFIG_TARGET_DEVICE_NAME_FLAGS;
 
 typedef struct DISPLAYCONFIG_TARGET_DEVICE_NAME
 {
-    DISPLAYCONFIG_DEVICE_INFO_HEADER            header;
-    DISPLAYCONFIG_TARGET_DEVICE_NAME_FLAGS      flags;
-    UINT32 /*DISPLAYCONFIG_VIDEO_OUTPUT_TECHNOLOGY*/       outputTechnology;
-    UINT16                                      edidManufactureId;
-    UINT16                                      edidProductCodeId;
-    UINT32                                      connectorInstance;
-    WCHAR                                       monitorFriendlyDeviceName[64];
-    WCHAR                                       monitorDevicePath[128];
+    DISPLAYCONFIG_DEVICE_INFO_HEADER header;
+    DISPLAYCONFIG_TARGET_DEVICE_NAME_FLAGS flags;
+    UINT32 /*DISPLAYCONFIG_VIDEO_OUTPUT_TECHNOLOGY*/ outputTechnology;
+    UINT16 edidManufactureId;
+    UINT16 edidProductCodeId;
+    UINT32 connectorInstance;
+    WCHAR monitorFriendlyDeviceName[64];
+    WCHAR monitorDevicePath[128];
 } DISPLAYCONFIG_TARGET_DEVICE_NAME;
 
-#define QDC_ONLY_ACTIVE_PATHS                         0x00000002
+#define QDC_ONLY_ACTIVE_PATHS 0x00000002
 
 #endif /* WINVER < 0x0601 */
 
 #ifndef HAVE_SHELLSCALINGAPI_H
 
-typedef enum MONITOR_DPI_TYPE {
+typedef enum MONITOR_DPI_TYPE
+{
     MDT_EFFECTIVE_DPI = 0,
     MDT_ANGULAR_DPI = 1,
     MDT_RAW_DPI = 2,
     MDT_DEFAULT = MDT_EFFECTIVE_DPI
 } MONITOR_DPI_TYPE;
 
-typedef enum PROCESS_DPI_AWARENESS {
+typedef enum PROCESS_DPI_AWARENESS
+{
     PROCESS_DPI_UNAWARE = 0,
     PROCESS_SYSTEM_DPI_AWARE = 1,
     PROCESS_PER_MONITOR_DPI_AWARE = 2
@@ -299,7 +300,8 @@ typedef enum PROCESS_DPI_AWARENESS {
 
 #ifndef _DPI_AWARENESS_CONTEXTS_
 
-typedef enum DPI_AWARENESS {
+typedef enum DPI_AWARENESS
+{
     DPI_AWARENESS_INVALID = -1,
     DPI_AWARENESS_UNAWARE = 0,
     DPI_AWARENESS_SYSTEM_AWARE = 1,
@@ -324,8 +326,8 @@ DECLARE_HANDLE(DPI_AWARENESS_CONTEXT);
 #define DPI_AWARENESS_CONTEXT_UNAWARE_GDISCALED ((DPI_AWARENESS_CONTEXT)-5)
 #endif /* NTDDI_VERSION < 0x0A000006 */
 
-typedef BOOL  (*PFNSHFullScreen)(HWND, DWORD);
-typedef void  (*PFCoordTransform)(SDL_Window*, POINT*);
+typedef BOOL (*PFNSHFullScreen)(HWND, DWORD);
+typedef void (*PFCoordTransform)(SDL_Window *, POINT *);
 
 typedef struct
 {
@@ -336,14 +338,16 @@ typedef struct
 
 #ifndef SDL_DISABLE_WINDOWS_IME
 /* Definition from Win98DDK version of IMM.H */
-typedef struct tagINPUTCONTEXT2 {
+typedef struct tagINPUTCONTEXT2
+{
     HWND hWnd;
     BOOL fOpen;
     POINT ptStatusWndPos;
     POINT ptSoftKbdPos;
     DWORD fdwConversion;
     DWORD fdwSentence;
-    union {
+    union
+    {
         LOGFONTA A;
         LOGFONTW W;
     } lfFont;
@@ -370,7 +374,8 @@ typedef struct SDL_VideoData
 
 #if !defined(__XBOXONE__) && !defined(__XBOXSERIES__) /* Xbox doesn't support user32/shcore*/
     /* Touch input functions */
-    void* userDLL;
+    void *userDLL;
+    /* *INDENT-OFF* */ /* clang-format off */
     BOOL (WINAPI *CloseTouchInputHandle)( HTOUCHINPUT );
     BOOL (WINAPI *GetTouchInputInfo)( HTOUCHINPUT, UINT, PTOUCHINPUT, int );
     BOOL (WINAPI *RegisterTouchWindow)( HWND, ULONG );
@@ -384,19 +389,22 @@ typedef struct SDL_VideoData
     UINT (WINAPI *GetDpiForWindow)( HWND );
     BOOL (WINAPI *AreDpiAwarenessContextsEqual)(DPI_AWARENESS_CONTEXT, DPI_AWARENESS_CONTEXT);
     BOOL (WINAPI *IsValidDpiAwarenessContext)(DPI_AWARENESS_CONTEXT);
+    /* *INDENT-ON* */ /* clang-format on */
 
-    void* shcoreDLL;
+    void *shcoreDLL;
+    /* *INDENT-OFF* */ /* clang-format off */
     HRESULT (WINAPI *GetDpiForMonitor)( HMONITOR         hmonitor,
                                         MONITOR_DPI_TYPE dpiType,
                                         UINT             *dpiX,
                                         UINT             *dpiY );
     HRESULT (WINAPI *SetProcessDpiAwareness)(PROCESS_DPI_AWARENESS dpiAwareness);
-#endif /*!defined(__XBOXONE__) && !defined(__XBOXSERIES__)*/
+    /* *INDENT-ON* */ /* clang-format on */
+#endif                /*!defined(__XBOXONE__) && !defined(__XBOXSERIES__)*/
 
     SDL_bool dpi_scaling_enabled;
     SDL_bool cleared;
 
- #ifndef SDL_DISABLE_WINDOWS_IME
+#ifndef SDL_DISABLE_WINDOWS_IME
     SDL_bool ime_com_initialized;
     struct ITfThreadMgr *ime_threadmgr;
     SDL_bool ime_initialized;
@@ -407,13 +415,13 @@ typedef struct SDL_VideoData
     SDL_bool ime_suppress_endcomposition_event;
     HIMC ime_himc;
 
-    WCHAR* ime_composition;
+    WCHAR *ime_composition;
     int ime_composition_length;
     WCHAR ime_readingstring[16];
     int ime_cursor;
 
     SDL_bool ime_candlist;
-    WCHAR* ime_candidates;
+    WCHAR *ime_candidates;
     DWORD ime_candcount;
     DWORD ime_candref;
     DWORD ime_candsel;
@@ -428,13 +436,15 @@ typedef struct SDL_VideoData
     int ime_winheight;
 
     HKL ime_hkl;
-    void* ime_himm32;
+    void *ime_himm32;
+    /* *INDENT-OFF* */ /* clang-format off */
     UINT (WINAPI *GetReadingString)(HIMC himc, UINT uReadingBufLen, LPWSTR lpwReadingBuf, PINT pnErrorIndex, BOOL *pfIsVertical, PUINT puMaxReadingLen);
     BOOL (WINAPI *ShowReadingWindow)(HIMC himc, BOOL bShow);
     LPINPUTCONTEXT2 (WINAPI *ImmLockIMC)(HIMC himc);
     BOOL (WINAPI *ImmUnlockIMC)(HIMC himc);
     LPVOID (WINAPI *ImmLockIMCC)(HIMCC himcc);
     BOOL (WINAPI *ImmUnlockIMCC)(HIMCC himcc);
+    /* *INDENT-ON* */ /* clang-format on */
 
     SDL_bool ime_uiless;
     struct ITfThreadMgrEx *ime_threadmgrex;
@@ -452,10 +462,11 @@ typedef struct SDL_VideoData
 } SDL_VideoData;
 
 extern SDL_bool g_WindowsEnableMessageLoop;
+extern SDL_bool g_WindowsEnableMenuMnemonics;
 extern SDL_bool g_WindowFrameUsableWhileCursorHidden;
 
 typedef struct IDirect3D9 IDirect3D9;
-extern SDL_bool D3D_LoadDLL( void **pD3DDLL, IDirect3D9 **pDirect3D9Interface );
+extern SDL_bool D3D_LoadDLL(void **pD3DDLL, IDirect3D9 **pDirect3D9Interface);
 
 extern SDL_bool WIN_IsPerMonitorV2DPIAware(_THIS);
 
